@@ -1,10 +1,9 @@
 package SSIS::Package::ConnectionManager::FLATFILE;
 
 use 5.010;
-use strict;
-use warnings;
+use Mouse;
 
-use parent qw/SSIS::Package::ConnectionManager/;
+extends 'SSIS::Package::ConnectionManager';
 
 =head1 NAME
 
@@ -12,11 +11,11 @@ SSIS::Package::ConnectionManager::FLATFILE - SSIS FLATFILE package connection ma
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 1 ;
