@@ -39,16 +39,7 @@ use SSIS::Package::DTSTask::Exec80PackageTask;
 use SSIS::Package::DTSTask::SSISSFTTask;
 use SSIS::Package::DTSTask::DbMaintenanceBackupTask;
 use SSIS::Package::DTSTask::DbMaintenanceCheckIntegrityTask;
-use SSIS::Package::DTSTask::DbMaintenanceExecuteAgentJobTask;
-use SSIS::Package::DTSTask::DbMaintenanceTSQLExecuteTask;
-use SSIS::Package::DTSTask::DbMaintenanceHistoryCleanupTask;
-use SSIS::Package::DTSTask::DbMaintenanceFileCleanupTask;
-use SSIS::Package::DTSTask::DbMaintenanceNotifyOperatorTask;
-use SSIS::Package::DTSTask::DbMaintenanceReindexTask;
-use SSIS::Package::DTSTask::DbMaintenanceDefragmentIndexTask;
-use SSIS::Package::DTSTask::DbMaintenanceShrinkTask;
-use SSIS::Package::DTSTask::DbMaintenanceUpdateStatisticsTask;
-use SSIS::Package::DTSTaskConnection;
+
 
 use XML::Simple ; #qw(:strict);
 #use XML::LibXML;
@@ -66,11 +57,11 @@ SSIS::Package::DTSTaskFactory - Factory class for SSIS package DTS tasks by Ded
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-
+our $VERSION = '0.01';
 
 
 
@@ -86,8 +77,8 @@ sub make {
 #    my $xml = $_[0] ;
 #warn Dumper $xml;   
     my $rh_args = $_[0];
-#warn Dumper $rh_args;   
-#my $obj = SSIS::Package::DTSTaskFactory->make( { type => $x->{'DTS:ExecutableType'}, properties =>  $x->{'DTS:Property'}, connectors => \@connectors  );
+
+#my $obj = SSIS::Package::DTSTaskFactory->make( { type => $x->{'DTS:ExecutableType'}, properties =>  $x->{'DTS:Property'} );
 
     
 #    my @type    = grep { $_->{'DTS:Name'} eq 'CreationName' }  @{$xml->{'DTS:Property'}};
@@ -100,37 +91,12 @@ sub make {
 #    my $name    = $name[0]->{content};
 
     my $objType = $rh_args->{type} ;
-#    my @name    = grep { $_->{'DTS:Name'} eq 'ObjectName' }    @{$rh_args->{properties}};    
-#    my $name    = $name[0]->{content};
+    my @name    = grep { $_->{'DTS:Name'} eq 'ObjectName' }    @{$rh_args->{properties}};    
+    my $name    = $name[0]->{content};
 
 #warn Dumper $objType;
 #warn Dumper $name;
 
-    my @connectors;
-#warn Dumper $rh_args->{connectors};
-    foreach my $c (@{$rh_args->{connectors}}) {
-#warn Dumper $c;
-#warn Dumper ref($c);
-        if ( ref($c) eq 'ARRAY' ) {
-            foreach my $member (@{$c}) {
-                if ( ref($member) eq 'ARRAY' ) {
-                    foreach my $mem2 (@{$member}) {
-                        my $conn = SSIS::Package::DTSTaskConnection->new($mem2->{connection}) ;
-                        push @connectors, $conn;
-                    }
-                }
-                else {
-#warn Dumper $member;                
-                    my $conn = SSIS::Package::DTSTaskConnection->new($member->{connection}) ;
-                    push @connectors, $conn;
-                }
-            }
-        }
-        else {
-            my $conn = SSIS::Package::DTSTaskConnection->new($c->{connection}) ;
-            push @connectors, $conn;
-        }
-    }
    
     if ( $objType =~ m{\A Microsoft\.SqlServer\.Dts\.Tasks\.(\w+) }xmisg ) {
         $objType  =  $1;
@@ -164,14 +130,8 @@ sub make {
         $objType = "ExecutePackageTask2" ; 
     }
 
-
-    my @valrefs = map { ( $_->{'DTS:Name'},$_->{'content'} ) ;} @{$rh_args->{properties}}; #@{$x->{'DTS:Property'}};
-    push @valrefs, 'Connectors', \@connectors;
-
 #warn Dumper $objType ;
-#    $task = "SSIS::Package::DTSTask::${objType}"->new( { 'Name' => $name } );    
-#warn Dumper @valrefs;
-    $task = "SSIS::Package::DTSTask::${objType}"->new( { (@valrefs) }  );    
+    $task = "SSIS::Package::DTSTask::${objType}"->new( { 'Name' => $name } );    
     
     #if ($objType =~ m{\A(ADONET|EXCEL|FILE|FLATFILE|MSMQ|OLEDB|SMOServer|SMTP)\z} ) {
 #            my @connstr = grep { $_->{'DTS:Name'} eq 'ConnectionString' }  @{$xml->{'DTS:ObjectData'}->{'DTS:ConnectionManager'}->{'DTS:Property'}};
